@@ -83,8 +83,10 @@ SELECT C.ID, C.NUMERO_COMANDA, C.DATA_COMANDA, T.NOM_LLARG_I_COMERCIAL
 FROM COMANDES C
 JOIN CLIENTS CL ON C.CLIENT_ID = CL.ID
 JOIN TERCERS T ON CL.TERCER_ID = T.ID
+JOIN COMANDES_DISTRIBUCIO CD ON C.ID = CD.COMANDA_ID
 left join SELECT_COMANDES_ESTATS_MAG(C.ID) CE ON C.ID = CE.COMANDA_ID
-where C.DATA_INICI IS NULL AND CE.MAG_PENDENT_SERVIR = 'S' AND C.DATA_ANULACIO IS NULL;
+where C.DATA_INICI IS NULL AND CE.MAG_PENDENT_SERVIR = 'S' AND C.DATA_ANULACIO IS NULL
+  and CD.REPARTIDOR_ID IS NOT NULL ;
 """
 
 
